Mississippi Supreme Court

Supreme Court Opinion Alphabetical Search Results 2013

Bailey Brake Farms, Inc. v. George Calvin Trout
2011-CA-00610-SCT | 3/22/2011 | Hand Down List
Kitchens, James W.
Blayde Grayson v. State of Mississippi
2012-DR-00059-SCT | 8/8/1997 | Hand Down List
Lamar, Ann H.
Charles H. Laney v. Martin Vance
2011-CA-00933-SCT | 6/1/2011 | Hand Down List
Pierce, Randy Grant
Christopher K. Taylor v. State of Mississippi
2011-KA-01911-SCT | 11/15/2011 | Hand Down List
King, Leslie D.
City of D'Iberville, Mississippi v. City of Biloxi, Mississippi
2010-AN-01050-SCT | 5/21/2010 | Hand Down List
King, Leslie D.
City of Jackson, Mississippi v. Alexander Gardner
2012-IA-00517-SCT |  | Hand Down List
Waller, William L., Jr.
City of Jackson, Mississippi v. Robert Sandifer, Jr.
2011-CA-01063-SCT | 5/12/2011 | Hand Down List
Lamar, Ann H.
Commonwealth Brands, Inc. v. J. Ed Morgan
2011-CA-01274-SCT | 8/18/2011 | Hand Down List
Randolph, Michael K.
Dante Lamar Evans v. State of Mississippi
2009-CT-00854-SCT | 3/12/2009 | Hand Down List
Chandler, David Anthony
David H. Nutt v. Derek A. Wyatt
2012-CA-00152-SCT | 12/22/2011 | Hand Down List
Randolph, Michael K.
David Javarious Jamison Renfro v. State of Mississippi
2012-KA-00643-SCT | 4/2/2012 | Hand Down List
Chandler, David Anthony
David W. Parvin v. State of Mississippi
2011-KA-01471-SCT | 6/17/2011 | Hand Down List
Kitchens, James W.
Derrick Arthur Burdette v. State of Mississippi
2012-KA-00447-SCT | 3/1/2012 | Hand Down List
Lamar, Ann H.
Donald Mitchell v. State of Mississippi
2011-KA-00684-SCT | 9/15/2010 | Hand Down List
Randolph, Michael K.
Edward Daniels v. State of Mississippi
2011-KA-00579-SCT | 3/3/2011 | Hand Down List
King, Leslie D.
Finis R. McFarland, Jr. v. D'Anne P. McFarland
2011-CA-00713-SCT | 4/15/2011 | Hand Down List
King, Leslie D.
Frankie L. Reasor v. Rose M. Johnson Jordan
2011-CA-01401-SCT | 8/17/2011 | Hand Down List
King, Leslie D.
Freddie Webber, Jr. v. State of Mississippi
2012-KA-00115-SCT |  | Hand Down List
Waller, William L., Jr.
GGNSC Batesville, LLC v. Catherine Johnson
2011-CA-01337-SCT |  | Hand Down List
King, Leslie D.
Harrison County Commercial Lot, LLC v. H. Gordon Myrick, Inc.
2010-CA-01865-SCT | 11/9/2010 | Hand Down List
King, Leslie D.
Herbert C. Hanson, Jr. v. John Gregory Disotell
2010-CT-01169-SCT | 6/29/2010 | Hand Down List
Dickinson, Jess H.
Holly Kathleen Jenkins McKnight v. Walter Calvin Jenkins
2011-CT-00206-SCT | 10/22/2008 | Hand Down List
Lamar, Ann H.
Jay McCalpin v. State of Mississippi
2011-CT-00269-COA | 1/21/2011 | Hand Down List
Lamar, Ann H.
Jones County School District v. Mississippi State Oil & Gas Board
2011-CA-00712-SCT | 5/2/2011 | Hand Down List
Pierce, Randy Grant
Kenton H. McNeese v. Katherine J. McNeese
2012-CP-00174-SCT | 12/31/2011 | Hand Down List
Coleman, Josiah Dennis
Laura Karpinsky v. American National Insurance Company
2010-CT-02084-SCT | 12/1/2010 | Hand Down List
Lamar, Ann H.
Marcus O'Neal Flowers v. State of Mississippi
2011-KA-01031-SCT | 4/13/2009 | Hand Down List
Lamar, Ann H.
Melissa Handy v. A. Waddell Nejam
2010-CT-01513-SCT |  | Hand Down List
Coleman, Josiah Dennis
Mississippi Commission on Judicial Performance v. Bruce B. Smith
2012-JP-01368-SCT |  | Hand Down List
Pierce, Randy Grant
Mississippi Commission on Judicial Performance v. Tommy Carver
2012-JP-00683-SCT |  | Hand Down List
Waller, William L., Jr.
Mississippi Department of Transportation v. Presley Y. Nosef
2012-IA-00280-SCT | 1/31/2012 | Hand Down List
Randolph, Michael K.
Mississippi State v. KCC, Inc.
2011-CA-01716-SCT | 10/26/2011 | Hand Down List
Chandler, David Anthony
Norma Slater Moore v. Christian T. Goeldner
2012-CA-00145-SCT | 1/3/2012 | Hand Down List
Chandler, David Anthony
Paul Tyler v. Automotive Finance Company, Inc.
2012-CA-00366-SCT | 1/31/2012 | Hand Down List
Coleman, Josiah Dennis
Rico Veazy v. State of Mississippi
2011-KA-00077-SCT | 12/14/2010 | Hand Down List
Lamar, Ann H.
Roundstone Development, LLC v. City of Natchez, Mississippi
2010-CT-00274-SCT | 1/14/2010 | Hand Down List
Waller, William L., Jr.
Sanctions v. Barbara Dunn
2011-CS-00255-SCT |  | Hand Down List
Kitchens, James W.
Shirley Alston v. Justin P. Pope
2010-CT-01760-SCT |  | Hand Down List
Pierce, Randy Grant
Shirley LaFontaine v. William Holliday
2012-CA-00346-SCT | 1/27/2012 | Hand Down List
Lamar, Ann H.
Southern Healthcare Services, Inc. v. Lloyd's of London
2011-CA-01833-SCT | 10/13/2011 | Hand Down List
Coleman, Josiah Dennis
Steve Antonio Anthony v. State of Mississippi
2010-CT-01004-SCT | 6/17/2010 | Hand Down List
Pierce, Randy Grant
T.C.B. Construction Company, Inc. v. W. C. Fore Trucking, Inc.
2010-CT-00177-SCT | 11/3/2009 | Hand Down List
Kitchens, James W.
Talib Ammer Hannah v. State of Mississippi
2011-KA-00515-SCT | 2/17/2011 | Hand Down List
Randolph, Michael K.
The Mississippi Bar v. James B. Galloway
2012-BD-01422-SCT |  | Hand Down List
Randolph, Michael K.
Tomarcus Monte Fulks v. State of Mississippi
2011-KA-00908-SCT | 5/27/2011 | Hand Down List
Chandler, David Anthony
Travis Keithley v. State of Mississippi
2010-KA-01581-SCT | 9/20/2010 | Hand Down List
Kitchens, James W.
Twonia Renee Williams v. State of Mississippi
2012-KA-00405-SCT | 2/16/2012 | Hand Down List
Randolph, Michael K.
Tyrell Williams v. State of Mississippi
2011-CT-00081-SCT | 12/7/2010 | Hand Down List
Coleman, Josiah Dennis
University of Mississippi Medical Center v. Donnie Foster
2010-CT-00791-SCT | 1/4/2010 | Hand Down List
Dickinson, Jess H.
Virginia College, LLC v. Cordero Blackmon
2012-CA-00463-SCT | 3/7/2012 | Hand Down List
Dickinson, Jess H.
William Martin Falkner v. John E. Stubbs, Jr.
2010-CT-01664-SCT | 9/1/2010 | Hand Down List
Chandler, David Anthony